@@ -132,12 +132,12 @@ Libexec::Libexec()
 
 void Libexec::postSym(const char *id, const char *value)
 {
-        const char *sid = head.getLast("SESSION");
-        if(!sid) 
-                return;
+	const char *sid = head.getLast("SESSION");
+	if(!sid)
+		return;
 
-        cout << sid << " POST " << id << " " << value << endl;
-} 
+	cout << sid << " POST " << id << " " << value << endl;
+}
 
 const char *Libexec::getArg(const char *id)
 {
@@ -276,6 +276,15 @@ void Libexec::detachSession(unsigned code)
 	tsid = NULL;
 }	
 
+void Libexec::sendError(const char *msg)
+{
+        if(!tsid)
+                return;
+
+        cout << tsid << " ERROR " << msg << endl;
+        tsid = NULL;
+}
+
 Bayonne::result_t Libexec::replayFile(const char *file)
 {
 	char buffer[512];
