@@ -249,12 +249,12 @@ void BayonneSysexec::run(void)
 var:
 			s->sysVar(tsid, var, value, size);
 		}
-		else if(!stricmp(cmd, "post"))
-		{
+                else if(!stricmp(cmd, "post"))
+                {
                         var = strtok_r(NULL, " \t\r\n", &tok); 
-                        value = strtok_r(NULL, " \t\r\n", &tok); 
-			s->sysPost(tsid, var, value);
-		}
+                        value = strtok_r(NULL, " \t\r\n", &tok);
+                        s->sysPost(tsid, var, value);
+                } 
 		else if(!stricmp(cmd, "flush"))
 			s->sysFlush(tsid);
 		else if(!stricmp(cmd, "wait"))
@@ -277,6 +277,8 @@ post:
                 }
 		else if(!stricmp(cmd, "exit"))
 			s->sysExit(tsid, tok);
+		else if(!stricmp(cmd, "error"))
+			s->sysError(tsid, tok);
 		else if(!stricmp(cmd, "record"))
 			s->sysRecord(tsid, tok);
 		else if(!stricmp(cmd, "replay"))
