@@ -97,6 +97,25 @@ BayonneSession::~BayonneSession()
 	finalize();
 }
 
+Script::Name *BayonneSession::getScript(const char *scr)
+{
+	ScriptImage **img;
+
+	if(!strnicmp(scr, "_local_::", 9))
+	{
+		img = getLocalImage(timeslot);
+		if(!img)
+			return NULL;
+
+		if(!*img)
+			return NULL;
+
+		return (*img)->getScript(scr);
+	}
+
+	return ScriptInterp::getScript(scr);
+} 
+
 void BayonneSession::initialize(void)
 {
 	setSid();
