@@ -513,6 +513,7 @@ unsigned BayonneTranslator::sayhour(BayonneSession *s, unsigned count, const cha
 	return count;
 }
 
+
 unsigned BayonneTranslator::addItem(BayonneSession *s, unsigned count, const char *text)
 {
 	s->state.audio.list[count++] = text;
@@ -577,14 +578,14 @@ const char *BayonneTranslator::speak(BayonneSession *s, Line *l)
 			count = sayhour(s, count, getToken(s, l, &idx));
 		else if(!stricmp(cp, "&weekday"))
 			count = weekday(s, count, getToken(s, l, &idx));
-		else if(!stricmp(cp, "&day"))
-			count = sayday(s, count, getToken(s, l, &idx));
-		else if(!stricmp(cp, "&daydate"))
-		{
-			cp = getToken(s, l, &idx);
-			count = weekday(s, count, cp);
-			count = sayday(s, count, cp);
-		}
+                else if(!stricmp(cp, "&day"))
+                        count = sayday(s, count, getToken(s, l, &idx));
+                else if(!stricmp(cp, "&daydate"))
+                {
+                        cp = getToken(s, l, &idx);
+                        count = weekday(s, count, cp);
+                        count = sayday(s, count, cp);
+                }
 		else if(!stricmp(cp, "&fulldate"))
 		{
 			cp = getToken(s, l, &idx);
@@ -654,7 +655,7 @@ BayonneTranslator *BayonneTranslator::loadTranslator(const char *id)
 #ifdef  WIN32
 #ifdef	HAVE_TESTING
         if(!prefix && provision_test)
-#ifdef  _DEBUG
+#ifdef  NDEBUG
                 prefix = "DEBUG";
 #else    
                 prefix = "RELEASE";
@@ -709,7 +710,7 @@ retry:
 		}
 
 		if(server)
-	                errlog("access", "cannot load translator %s", path);
+	                errlog("access", "cannot load %s", path);
                 return NULL;
         }
 
