@@ -148,7 +148,7 @@ static char *wdays[] = {"voskresenie", "ponedelnik", "vtornik",
 
 static unsigned lastnum(unsigned num)
 {
-	int divider = 100;
+	unsigned divider = 100;
 	while(num > 19)
 	{
 		if(num < divider)
@@ -634,7 +634,7 @@ unsigned RussianTranslator::saynumber(BayonneSession *s, unsigned count, const c
 
 	if(strchr(cp, '.'))
 	{
-		val = atof(cp);
+		val = (float)atof(cp);
 		val = val - int(val);	
 	}
 
