@@ -390,13 +390,22 @@ void Driver::startDriver(void)
 			data_negotiate, info.rate);
 		break;
 	case pcm16Mono:
-		snprintf(cbuf, sizeof(cbuf), "%d L16_1CH/%d",
+		snprintf(cbuf, sizeof(cbuf), "%d L16/%d",
 			data_negotiate, info.rate);
 		break;
 	case pcm16Stereo:
 		snprintf(cbuf, sizeof(cbuf), "%d L16_2CH/%d",
 			data_negotiate, info.rate);
 		break;
+	case speexVoice:
+		if(!data_negotiate)
+		{
+			data_negotiate = 97;
+			setValue("payload", "97");
+		}
+		snprintf(cbuf, sizeof(cbuf), "%d SPEEX/%d",
+			data_negotiate, info.rate);
+		break;
 	case gsmVoice:
 		if(!data_negotiate)
 		{
@@ -803,9 +812,10 @@ void Driver::run(void)
 	sdp_connection_t *conn;
 	osip_content_type_t *ct;
 	sdp_media_t *remote_media, *local_media, *audio_media;
-	char *tmp, *audio_payload;
+	char *tmp, *audio_payload, *adp;
 	const char *data_rtpmap;
-	int pos, mpos, rtn;
+	int pos, mpos, rtn, apos;
+	sdp_attribute_t *attr;
 	char *sdp;
 	bool reg_inband;
 	uint8 reg_payload;
@@ -1443,16 +1453,37 @@ sip415:
 			{
 			case mulawAudio:
 				session->data_payload = 0;
-				data_rtpmap = "a=rtpmap:0 PCMU/8000/1";
+				data_rtpmap = "PCMU/8000/1";
 				break;
 			case alawAudio:
 				session->data_payload = 8;
-				data_rtpmap = "a=rtpmap:8 PCMA/8000/1";
+				data_rtpmap = "PCMA/8000/1";
+				break;
+			case speexVoice:
+				session->data_payload = 97;
+				data_rtpmap = "SPEEX/8000/1";
 				break;
 			case gsmVoice:
 				session->data_payload = 3;
-				data_rtpmap = "a=rtpmap:3 GSM/8000/1";
+				data_rtpmap = "GSM/8000/1";
 				break;
+			case pcm16Stereo:
+				session->data_payload = 98;
+				data_rtpmap = "L16/11025/2";
+				session->info.rate = 11025;
+				break;
+			case pcm16Mono:
+				switch(session->info.rate)
+				{
+				case 16000:
+					session->data_payload = 98;
+					data_rtpmap = "L16/16000/1";
+					break;
+				default:
+					session->info.rate = 8000;
+					session->data_payload = 97;
+					data_rtpmap = "L16/8000/1";
+				}
 			}
 			audio_payload = NULL;
 			while(!osip_list_eol(remote_sdp->m_medias, mpos))
@@ -1469,7 +1500,43 @@ sip415:
 				audio_payload = NULL;
 				tmp = NULL;
 				pos = 0;
-				while(!osip_list_eol(remote_media->m_payloads, pos))
+				
+				while(!osip_list_eol(remote_media->a_attributes, pos))
+				{
+					attr = (sdp_attribute_t *)osip_list_get(remote_media->a_attributes, pos++);
+					if(!attr)
+						continue;
+					tmp = attr->a_att_value;
+					if(!tmp)
+						continue;
+				
+					if(stricmp(attr->a_att_field, "rtpmap"))
+						continue;
+ 	
+					adp = tmp;
+					tmp = strchr(tmp, ' ');
+					if(!tmp)
+					{
+						adp = NULL;
+						continue;
+					}
+					
+					while(isspace(*tmp))
+						++tmp;
+					if(!strnicmp(tmp, "telephone-event/", 16))
+					{
+						session->dtmf_payload = atoi(adp);
+						continue;
+					}
+					if(!strnicmp(tmp, data_rtpmap, strlen(tmp)))
+					{
+						audio_payload = adp;
+						session->data_payload = atoi(adp);
+					}
+ 				}
+			
+				pos = 0;
+				while(!osip_list_eol(remote_media->m_payloads, pos) && !audio_payload)
 				{
 					tmp = (char *)osip_list_get(remote_media->m_payloads, pos++);
 					if(!tmp || !*tmp)
@@ -1491,6 +1558,11 @@ sip415:
 			if(!audio_payload)
 				goto sip415;
 
+			snprintf(cbuf, sizeof(cbuf), "a=rtpmap:%d %s",
+				session->data_payload, data_rtpmap);
+			session->setConst("session.rtpmap", cbuf);
+			data_rtpmap = session->getSymbol("session.rtpmap");
+
 			if(session->dtmf_payload)
 				snprintf(cbuf, sizeof(cbuf),
 					"m=audio %d RTP/AVP %d %d\r\n"
@@ -1509,8 +1581,6 @@ sip415:
 				
 			addString(sdp, 4096, cbuf);
 
-			session->setConst("session.rtpmap", data_rtpmap);
-
 			if(session->dtmf_sipinfo)
 				session->setConst("session.dtmfmode", "info");
 			else if(session->dtmf_payload)
