@@ -378,6 +378,18 @@ failure:
 
 		switch(info.encoding)
 		{
+		case pcm16Stereo:
+			data_payload = 98;
+			rtpmap = "a=rtpmap:98 L16/11025/2";
+			break;
+		case pcm16Mono:
+			data_payload = 97;
+			rtpmap = "a=rtpmap:97 L16/8000/1";
+			break;
+		case pcm8Mono:
+			data_payload = 96;
+			rtpmap = "a=rtpmap:96 L8/8000/1";
+			break;
 		case mulawAudio:
 			data_payload = 0;
 			rtpmap = "a=rtpmap:0 PCMU/8000/1";
@@ -390,6 +402,10 @@ failure:
 			data_payload = 3;
 			rtpmap = "a=rtpmap:3 GSM/8000/1";
 			break;
+		case speexVoice:
+			data_payload = 97;
+			rtpmap = "a=rtpmap:97 SPEEX/8000/1";
+			break;
 		}			
 		if(dtmf_payload)
                         snprintf(sdp, sizeof(sdp),
