@@ -27,208 +27,62 @@ TCPSession(server)
 	memset(monmap, 0, ts_used);
 }
 
-void Session::startSelect(const char *name, const char *dial, const char *caller, const char *display)
-{
-	BayonneSpan *span;
-	BayonneDriver *trunk = BayonneDriver::getTrunking();
-	BayonneSession *session;
-	ScriptImage *img = useImage();
-	Name *scr = img->getScript(name);
-	Event event;
-	Line *sel = scr->select;
-	unsigned idx = 0, count;
-	const char *cp;
-	timeslot_t pos;
-
-        if(!scr)
-                *tcp() << "*** unknown script specified" << endl;
-        else if(scr && scr->access != scrPUBLIC)
-                *tcp() << "*** invalid script specified" << end;
-
-	if(!scr || !scr->select || scr->access != scrPUBLIC)
-	{
-		endImage(img);
-		if(trunk && scr)
-		{
-			startDriver(trunk, name, dial, caller, display);
-			return;
-		}
-		if(scr && !scr->select && scr->access == scrPUBLIC)
-			*tcp() << "*** missing select records" << endl;
-		return;
-	}
-
-	while(sel)
-	{
-                idx = 0;
-                cp = strchr(sel->cmd, '.');
-                if(cp && !stricmp(cp, ".span"))
-                     while(NULL != (cp = sel->args[idx++]))
-                {
-                        span = BayonneSpan::get(atoi(cp));
-                        if(!span)   
-                                continue;
-
-                        pos = span->getFirst();
-                        count = span->getCount();     
-                        while(count--)
-                        {
-                                session = getSession(pos++);
-                                if(!session)
-                                        continue;
-
-                                session->enter();
-                                if(session->isIdle())
-                                        goto start;
-                                session->leave();
-                        }
-		}
-                else while(NULL != (cp = sel->args[idx++]))
-                {
-                        session = getSid(cp);
-                        if(!session)
-                                continue;
-
-                        session->enter();
-                        if(session->isIdle())
-                                goto start;
-                        session->leave();
-                }
-		sel = sel->next;
-
-	}
-	endImage(img);
-	*tcp() << "*** no selected ports available" << endl;
-	return;
-
-start:
-        memset(&event, 0, sizeof(event));
-        event.id = START_OUTGOING;
-        event.start.img = img; 
-        event.start.scr = scr;
-        event.start.dialing = dial;
-
-        session->setConst("session.caller", caller);
-        session->setConst("session.display", display);
-
-        if(!session->postEvent(&event))
-        {
-                *tcp() << "*** session unable to start" << endl;
-                session->leave();
-                endImage(img);
-                return;
-        }
-
-	*tcp() << "starting call " << session->getExternal("session.id") << endl; 
-	session->leave();
-	return;
-}
-
-void Session::startDriver(BayonneDriver *d, const char *name, const char *dial, const char *caller, const char *display)
-{
-        BayonneSession *session;
-        ScriptImage *img = useImage();
-        Name *scr = img->getScript(name);
-        Event event;
-
-	if(!d)
-		*tcp() << "*** invalid driver specified" << endl;
-	else if(!scr)
-		*tcp() << "*** unknown script specified" << endl;
-	else if(scr && scr->access != scrPUBLIC)
-		*tcp() << "*** invalid script specified" << end;
-
-	if(!d || !scr || scr->access != scrPUBLIC)
-	{
-		endImage(img);
-		return;
-	}
-
-        if(!caller)      
-        {
-                display = "bayonne";
-                caller = "none";
-        }
-
-        if(!display)
-                display = caller;
-
-
-        session = d->getIdle();
-        if(!session)
-        {
-		*tcp() << "*** no idle ports available" << endl;
-                endImage(img);  
-                return;
-        }
-
-        session->enter();
-        memset(&event, 0, sizeof(event));
-        event.id = START_OUTGOING;
-        event.start.img = img;
-        event.start.scr = scr;
-        event.start.dialing = dial;
-
-        session->setConst("session.caller", caller);
-        session->setConst("session.display", display);
-
-        if(!session->postEvent(&event))
-        {
-		*tcp() << "*** session unable to start" << endl;
-                session->leave();
-                endImage(img);  
-                return;
-        }
-
-	*tcp() << "starting call " << session->getExternal("session.id") << endl;
-	session->leave();
-	return;
-}
-
 void Session::help(void)
 {
 	*tcp() << "bye - disconnect session" << endl;
 	*tcp() << "calls [sid..] - display active calls" << endl;
 	*tcp() << "drivers [names..] - display loaded drivers" << endl;
+	*tcp() << "global id cmd [val] - manipulate global" << endl;
 	*tcp() << "mon state|all timeslots.. - enable state monitoring" << endl;
 	*tcp() << "nomon timeslots.. - disable state monitoring" << endl;
-	*tcp() << "paths - path configuration of server" << endl;
-        *tcp() << "reg [proto] - display protocol registrations" << endl;
+        *tcp() << "reg - display protocol registrations" << endl;
 	*tcp() << "reload - reload script configuration" << endl;
 	*tcp() << "shutdown - shutdown server" << endl;
 	*tcp() << "spans - list active spans in server" << endl;
-	*tcp() << "start script [num [cid]] - start a script running" << endl;
+	*tcp() << "start dial script [num [cid]] - start a script running" << endl;
 	*tcp() << "stat - show status line record" << endl;
 	*tcp() << "stop sid - stop a running session" << endl;
+	*tcp() << "submit script ... - submit job request" << endl;
 	*tcp() << "uptime - show current server uptime" << endl;
 }
 
-void Session::paths(void)
+void Session::reg(void)
 {
-	char path[128];
+	regauth_t *data;
+	unsigned count, idx = 0;
+	char buf[80];
+	BayonneDriver *d = BayonneDriver::getPrimary();
 
-	snprintf(path, sizeof(path),
-		"audio prompts: %s", Bayonne::server->getLast("prompts"));
-	snprintf(path, sizeof(path),
-		"config files:  %s", Script::etc_prefix);
-	*tcp() << path << endl;
-	snprintf(path, sizeof(path), 
-		"data files:    %s", Script::var_prefix);
-	*tcp() << path << endl;
-	snprintf(path, sizeof(path),
-		"log files:     %s", Script::log_prefix);
-	*tcp() << path << endl;
-	snprintf(path, sizeof(path),
-		"run files:     %s", Bayonne::server->getLast("runfiles"));
-	*tcp() << path << endl;
-	snprintf(path, sizeof(path),
-		"script files:  %s", Bayonne::server->getLast("scripts"));
-	*tcp() << path << endl;
-	snprintf(path, sizeof(path),
-		"script macros: %s", Bayonne::server->getLast("include"));
-	*tcp() << path << endl;
+	if(!d)
+	{
+		*tcp() << "*** invalid driver or no protocols" << endl;
+		return;
+	}
+
+	data = new regauth_t[1024];
+	count = d->getRegistration(data, 1024);
+	if(!count)
+	{
+		*tcp() << "*** no active registrations" << endl;
+		return;
+	}
+
+	snprintf(buf, sizeof(buf), "%22s %16s %6s %8s",
+		"remote", "userid", "type", "status");
+	*tcp() << buf << endl;
+	while(idx < count)
+	{
+		snprintf(buf, sizeof(buf), "%22s %16s %6s %8s",
+			data[idx].remote, data[idx].userid,
+			data[idx].type, data[idx].status);
+		*tcp() << buf << endl;
+		++idx;
+	}
+
+	delete[] data;
 }
 
+
 void Session::uptime(void)
 {
 	unsigned long upt = Bayonne::uptime();
@@ -408,42 +262,7 @@ void Session::allcalls(void)
 		*tcp() << "*** no active calls found" << endl;
 }
 
-void Session::reg(BayonneDriver *d)
-{
-	const char *proto;
-	regauth_t *data;
-	unsigned count, idx = 0;
-	char buf[80];
 
-	if(!d)
-	{
-		*tcp() << "*** invalid driver or no protocols" << endl;
-		return;
-	}
-
-	data = new regauth_t[1024];
-	count = d->getRegistration(data, 1024);
-	if(!count)
-	{
-		*tcp() << "*** no active registrations" << endl;
-		return;
-	}
-
-	snprintf(buf, sizeof(buf), "%22s %16s %6s %8s",
-		"remote", "userid", "type", "status");
-	*tcp() << buf << endl;
-	while(idx < count)
-	{
-		snprintf(buf, sizeof(buf), "%22s %16s %6s %8s",
-			data[idx].remote, data[idx].userid,
-			data[idx].type, data[idx].status);
-		*tcp() << buf << endl;
-		++idx;
-	}
-
-	delete[] data;
-}
-	
 
 void Session::spans(void)
 {
@@ -491,6 +310,7 @@ void Session::run(void)
 	char *argv[128];
 	char *tok;
 	char *bp;
+	const char *val;
 	int argc;
 	tpport_t port;
 	IPV4Address addr = getLocal(&port);
@@ -555,6 +375,61 @@ void Session::run(void)
 				login = false;
 				break;
 			}
+                        else if(!strnicmp(*argv, "reg", 3))
+                        {
+                                reg();
+                        }
+			else if(!stricmp(*argv, "global"))
+			{
+				if(!argv[1])
+				{
+					*tcp() << "*** symbol id missing" << endl;
+					goto skip;
+				}
+				if(!argv[2])
+				{
+					*tcp() << "*** symbol command missing" << endl;
+					goto skip;
+				}
+				if(!stricmp(argv[2], "clear"))
+				{
+					if(!BayonneSession::clearGlobal(argv[1]))
+						*tcp() << "*** cannot find symbol" << endl;
+ 					goto skip;
+				}
+				if(!stricmp(argv[2], "get"))
+				{
+					val = BayonneSession::getGlobal(argv[1]);
+					if(!val)
+						*tcp() << "*** cannot find symbol" << endl;
+					else
+						*tcp() << argv[1] << " = [" << val << "]" << endl;
+					goto skip;
+				}
+				if(!argv[3])
+				{
+					*tcp() << "*** symbol size or value missing" << endl;
+					goto skip;
+				}
+				if(!stricmp(argv[2], "size"))
+				{
+					if(!BayonneSession::sizeGlobal(argv[1], atoi(argv[3])))
+						*tcp() << "*** cannot find symbol" << endl;
+					goto skip;
+				}
+				if(!stricmp(argv[2], "set"))
+				{
+					if(!BayonneSession::setGlobal(argv[1], argv[3]))
+						*tcp() << "*** cannot find symbol" << endl;
+					goto skip;
+				}
+				if(!stricmp(argv[2], "add"))
+				{
+					if(!BayonneSession::addGlobal(argv[1], argv[3]))
+						*tcp() << "*** cannot find symbol" << endl;
+					goto skip;
+				}
+			}	
 			else if(!strnicmp(*argv, "nomon", 5))
 			{
 				nomon(&argv[1]);
@@ -580,6 +455,13 @@ void Session::run(void)
 				else
 					allcalls();
 			}
+			else if(!stricmp(*argv, "submit"))
+			{
+				if(!argv[1])
+					*tcp() << "*** missing submit name" << endl;
+				if(!BayonneBinder::submitRequest((const char **)&argv[1]))
+					*tcp() << "*** submit request failed" << endl;
+			}
 			else if(!stricmp(*argv, "spans"))
 				spans();
 			else if(!stricmp(*argv, "drivers"))
@@ -588,24 +470,29 @@ void Session::run(void)
 					BayonneDriver::list(&argv[1], 120);
 				drivers(&argv[1]);
 			}
-			else if(!stricmp(*argv, "reg"))
-			{
-				if(argv[1])
-					reg(BayonneDriver::get(argv[1]));
-				else
-					reg(BayonneDriver::getProtocol());
-			}		
 			else if(!stricmp(*argv, "start"))
 			{
 				if(!argv[1])
+				{
+					*tcp() << "*** dial destination missing" << endl;
+					goto skip;
+				}
+
+				if(!argv[2])
 				{
 					*tcp() << "*** missing script name" << endl;
 					goto skip;
 				}
-				if(argv[2])
-					startSelect(argv[1], argv[2], argv[3], argv[4]);
+
+				session = Bayonne::startDialing(argv[1], 
+					argv[2], argv[3], argv[4]);
+				if(!session)
+					*tcp() << "*** session unable to start call" << endl;
 				else
-					startSelect(argv[1], NULL, NULL, NULL);
+				{
+					*tcp() << "starting call " << session->getExternal("session.id") << endl;
+					session->leave();
+				}
 			}
 			else if(!stricmp(*argv, "stop"))
 			{
@@ -635,8 +522,6 @@ void Session::run(void)
 				Bayonne::reload();
 			else if(!stricmp(*argv, "help"))
 				help();
-			else if(!stricmp(*argv, "paths"))
-				paths();
 			else if(!stricmp(*argv, "shutdown"))
 			{
 				Service::active = false;
