@@ -14,8 +14,6 @@
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-#include <cc++/process.h>
-#include <cc++/slog.h>
 #include "server.h"
 
 #ifndef	WIN32
@@ -26,30 +24,6 @@ namespace server {
 using namespace ost;
 using namespace std;
 
-#if defined(_MSC_VER) && _MSC_VER >= 1300
-#if defined(_WIN64_) || defined(__WIN64__)
-#define RLL_SUFFIX ".x64"
-#elif defined(_M_IX86)
-#define RLL_SUFFIX ".x86"
-#else
-#define RLL_SUFFIX ".xlo"
-#endif
-#endif
-
-#if defined(__MINGW32__) | defined(__CYGWIN32__)
-#define RLL_SUFFIX ".dso"
-#endif
-
-#ifdef  W32
-#ifndef RLL_SUFFIX
-#define RLL_SUFFIX ".rll"
-#endif
-#endif
-
-#ifndef RLL_SUFFIX
-#define RLL_SUFFIX ".dso"
-#endif
-
 #ifdef	WIN32
 #define	PROMPT_FILES	"C:\\Program Files\\GNU Telephony\\Phrasebook Audio"
 #define	SCRIPT_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Scripts"
@@ -92,9 +66,6 @@ static Keydata::Define paths[] = {
 #endif
 	{NULL, NULL}};
 
-static Keydata::Define protocols[] = {
-	{NULL, NULL}};
-
 static Keydata::Define server[] = {
 	{"user", "bayonne"},
 	{"group", "bayonne"},
@@ -105,6 +76,7 @@ static Keydata::Define server[] = {
 	{"logging", "warn"},
 	{"monitoring", "tcp"},
 	{"binding", "default"},
+	{"definitions", "url"},
 	{NULL, NULL}};
 
 static Keydata::Define engine[] = {
@@ -115,22 +87,45 @@ static Keydata::Define engine[] = {
 	{"userid", ""},
 	{"secret", ""},
 	{"timeslots", "32"},
-#ifndef	WIN32
-	{"trunking", "autodetect"},
-	{"protocol", "default"},
-#endif
+	{"driver", "autodetect"},
+	{"protocol", "none"},
+	{NULL, NULL}};
+
+static Keydata::Define libkeys[] = {
+	{"filesystem", VAR_FILES},
+	{"interface", "eth0"},
+	{"limit", "0"},
+	{NULL, NULL}};
+
+static Keydata::Define smtpkeys[] = {
+	{"limit", "0"},
+	{"sendmail", "/usr/sbin/sendmail"},
+	{"sender", "bayonne@localhost.localdomain"},
+	{"from", "Bayonne Server <bayonne@localhost.localdomain>"},
+	{"errors", "postmaster@localhost.localdomain"}, 
+	{NULL, NULL}};
+
+static Keydata::Define urlkeys[] = {
+	{"limit", "0"},
+	{"prefix", "http://localhost"},
+	{"agent", "bayonne/" VERSION},
 	{NULL, NULL}};
 
 #ifdef	WIN32
 Keydata keypaths(paths, "/bayonne/paths");
 Keydata keyserver(server, "/bayonne/server");
 Keydata keyengine(engine, "/bayonne/engine");
-Keydata keyprotocols(protocols, "/bayonne/protocols");
+BayonneConfig keylibexec("libexec", libkeys, "/bayonne/libexec");
+BayonneConfig keysmtp("smtp", smtpkeys, "/bayonne/smtp");
+BayonneConfig keyurl("url", urlkeys, "/bayonne/url");
 #else
 Keydata keypaths(paths, "/bayonne/server/paths");
 Keydata keyserver(server, "/bayonne/server/server");
 Keydata keyengine(engine, "/bayonne/server/engine");
-Keydata keyprotocols(protocols, "/bayonne/server/protocols");
+BayonneConfig keylibexec("libexec", libkeys, "/bayonne/server/libexec");
+BayonneConfig keysmtp("smtp", smtpkeys, "/bayonne/server/smtp");
+BayonneConfig keyurl("url", urlkeys, "/bayonne/server/url");
+
 #endif
 Keydata keyoptions;
 
@@ -142,6 +137,7 @@ void liveConfig(void)
 	char *p, *sp, *tok;
 	const char *cp;
 	unsigned timeslots = atoi(keyengine.getLast("timeslots"));
+	Bayonne::timeslot_t overdraft = 1;
 
 #ifdef	WIN32
         char nodename[MAX_COMPUTERNAME_LENGTH + 1];
@@ -223,9 +219,27 @@ void liveConfig(void)
 
 #endif
         sp = (char *)keyserver.getLast("definitions");
+
+	if(sp && !stricmp(sp, "default"))
+	{
+		sp = NULL;
+		cp = Process::getEnv("DEFINES");
+		if(cp)
+		{
+			setString(path, sizeof(path), cp);
+			sp = path;
+		}
+	}
+
         if(sp && !stricmp(sp, "none"))
                 sp = NULL;
 
+	if(sp && !stricmp(sp, "off"))
+	{
+		sp = NULL;
+		Bayonne::provision_defines = false;
+	}
+
         if(sp && !*sp)
                 sp = NULL;
         if(sp)
@@ -245,12 +259,11 @@ void liveConfig(void)
 
 	cp = keyoptions.getLast("prefix");
 #ifdef	WIN32
-	if(cp && *cp && !Bayonne::provision_test)
-		chdir(cp);
-#else
+	if(Bayonne::provision_test)
+		cp = NULL;
+#endif
 	if(cp && *cp)
 		chdir(cp);
-#endif
 
 	env = Process::getEnv("LANG");
 	if(env)
@@ -314,12 +327,14 @@ void liveConfig(void)
                 keypaths.getLast("logfiles"), keyserver.getLast("node"));
         runtime.setValue("stats", path);
 
+	runtime.setValue("runlevel.conf", CONFIG_FILES "/runlevel.conf");
 	runtime.setValue("include", keypaths.getLast("macros"));
 	keypaths.setValue("include", keypaths.getLast("macros"));
 	runtime.setValue("tmp", keypaths.getLast("tmp"));
 	runtime.setValue("tmpfs", keypaths.getLast("tmpfs"));
 	runtime.setValue("prompts", keypaths.getLast("prompts"));
 	runtime.setValue("prefix", keypaths.getLast("datafiles"));
+	runtime.setValue("config", keypaths.getLast("config"));
 	runtime.setValue("voice", keyserver.getLast("voice"));
 	runtime.setValue("logfiles", keypaths.getLast("logfiles"));
 	runtime.setValue("runfiles", keypaths.getLast("runfiles"));
@@ -383,7 +398,11 @@ void liveConfig(void)
 #endif
 	Script::exec_token = "bayonne:";
 
-        Bayonne::allocate(timeslots, dynamic_cast<ScriptCommand *>(&runtime)); 
+	cp = keyengine.getLast("virtual");
+	if(cp)
+		overdraft = atoi(cp);
+
+        Bayonne::allocate(timeslots, dynamic_cast<ScriptCommand *>(&runtime), overdraft); 
 }
 
 #ifdef	HAVE_TESTING
@@ -437,6 +456,9 @@ void loadConfig(void)
 	keypaths.loadFile(pbuf, "paths");
 	keyserver.loadFile(pbuf, "server");
 	keyengine.loadFile(pbuf, "engine");
+	keylibexec.loadFile(pbuf, "libexec");
+	keysmtp.loadFile(pbuf, "smtp");
+	keyurl.loadFile(pbuf, "url");
 	runtime.loadFile(pbuf, "virtual", "virtual");
 
 	snprintf(pbuf, sizeof(pbuf), "%s/driver.ini", config);
@@ -470,7 +492,8 @@ void loadConfig(void)
 		keypaths.load("~bayonne/paths");
 		keyserver.load("~bayonne/server");
 		keyengine.load("~bayonne/engine");
-		keyprotocols.load("~bayonne/protocols");
+		keysmtp.load("~bayonne/smtp");
+		keyurl.load("~bayonne/url");
 		runtime.loadPrefix("virtual", "~bayonne/virtual");
 	}
 
@@ -479,7 +502,9 @@ void loadConfig(void)
 		keypaths.load("/bayonne/provision/paths");
 		keyserver.load("/bayonne/provision/server");
 		keyengine.load("/bayonne/provision/engine");
-		keyprotocols.load("/bayonne/provision/protocols");
+		keylibexec.load("/bayonne/provision/libexec");
+		keysmtp.load("/bayonne/provision/smtp");
+		keyurl.load("/bayonne/provision/url");
 		runtime.loadPrefix("virtual", "/bayonne/provision/virtual");
 	}
 
@@ -523,10 +548,10 @@ live:
 	keyoptions.setValue("prefix", keypaths.getLast("datafiles"));
 	keyserver.setValue("state", "live");
 
-#ifdef  SCRIPT_SERVER_PREFIX
-        Script::var_prefix = keypaths.getLast("datafiles");
-        Script::etc_prefix = keypaths.getLast("config");
-        Script::log_prefix = keypaths.getLast("logfiles");
+#ifdef	SCRIPT_SERVER_PREFIX
+	Script::var_prefix = keypaths.getLast("datafiles");
+	Script::etc_prefix = keypaths.getLast("config");
+	Script::log_prefix = keypaths.getLast("logfiles");
 #endif
 
 	// only for live server...
@@ -545,30 +570,14 @@ bool parseConfig(char **argv)
 	unsigned minslots = 0;
 	bool live = true;
 
-#ifndef WIN32
+#ifndef	WIN32
 	const char *cp;
-
-        cp = keyengine.getLast("trunking");
-        if(cp && !stricmp(cp, "autodetect"))
-	{
-                cp = Process::getEnv("TIMESLOTS");
-		goto setenv;
-	}
-        else if(cp && !stricmp(cp, "default"))
-	{
-                cp = Process::getEnv("TIMESLOTS");
-		goto setenv;
-	}
-
-	cp = keyengine.getLast("protocol");
-	if(cp && !stricmp(cp, "default"))
-	{
+	cp = keyengine.getLast("driver");
+	if(cp && !stricmp(cp, "autodetect"))
+		cp = Process::getEnv("TIMESLOTS");
+	else if(cp && !stricmp(cp, "default"))
 		cp = Process::getEnv("TIMESLOTS");
-		goto setenv;
-	}
 
-	goto retry;
-setenv:
 	if(cp && atoi(cp) > 0)
 		keyengine.setValue("timeslots", cp);
 #endif
@@ -586,7 +595,7 @@ retry:
 
         if(!strnicmp("--", option, 2))
                 ++option;
-	
+
 	if(!strnicmp(option, "-driver=", 8))
 	{
 		keyengine.setValue("driver", option + 8);
@@ -594,19 +603,12 @@ retry:
 		goto retry;
 	} 
 
-	if(!strnicmp(option, "-trunking=", 10))
-        {
-                keyengine.setValue("trunking", option + 10);
-                ++argv;
-                goto retry;
-        }  
-
-        if(!strnicmp(option, "-protocol=", 10))     
-        {
-                keyengine.setValue("protocol", option + 10);
-                ++argv;
-                goto retry;
-        }   
+	if(!strnicmp(option, "-protocol=", 10))
+	{
+		keyengine.setValue("protocol", option + 10);
+		++argv;
+		goto retry;
+	}
 
         if(!strnicmp(option, "-bind=", 6))
         {
@@ -623,13 +625,6 @@ retry:
                 ++argv;
                 goto retry;
         }  
-
-	if(!stricmp(option, "-testing"))
-	{
-		++argv;
-		testConfig(argv0);
-		goto retry;
-	}
 	
 	if(!stricmp(option, "-test"))
 	{
@@ -671,8 +666,8 @@ retry:
                 ++argv;
                 goto retry;
         }
-#endif
-            
+#endif            
+
 	if(!stricmp(option, "-check"))
 	{
 		keyserver.setValue("logging", "debug");
@@ -824,19 +819,6 @@ retry:
                 goto retry;
         }
 
-
-        if(!stricmp(option, "-trunking"))
-        {
-                ++argv;
-                if(!*argv)
-                {
-                        cerr << "bayonne: -trunking: missing argument" << endl;
-                        exit(-1);
-                }
-                keyengine.setValue("trunking", *(argv++));
-                goto retry;
-        }
-            
         if(!stricmp(option, "-protocol"))
         {
                 ++argv;
@@ -847,7 +829,7 @@ retry:
                 }
                 keyengine.setValue("protocol", *(argv++));
                 goto retry;
-        } 
+        }
 
         if(!stricmp(option, "-bind"))
         {
