@@ -14,8 +14,6 @@
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-#include <cc++/process.h>
-#include <cc++/slog.h>
 #include "server.h"
 
 namespace server {
