@@ -14,34 +14,8 @@
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-#include <cc++/process.h>
-#include <cc++/slog.h>
-#include <cstdarg>
 #include "server.h"
-
-#if defined(_MSC_VER) && _MSC_VER >= 1300
-#if defined(_WIN64_) || defined(__WIN64__)     
-#define RLL_SUFFIX "x64"
-#elif defined(_M_IX86)
-#define RLL_SUFFIX "x86"
-#else
-#define RLL_SUFFIX "xlo"
-#endif
-#endif 
-
-#if defined(__MINGW32__) | defined(__CYGWIN32__)
-#define RLL_SUFFIX "dso"
-#endif
-
-#ifdef  W32
-#ifndef RLL_SUFFIX
-#define RLL_SUFFIX "rll"
-#endif
-#endif 
-
-#ifndef RLL_SUFFIX
-#define RLL_SUFFIX "dso"
-#endif 
+#include <cstdarg>
 
 namespace server {
 using namespace ost;
@@ -51,8 +25,6 @@ Runtime::Runtime() :
 ScriptRuntime()
 {
 	static ScriptInterp::Define interp[] = {
-		{"bgm", false, (Method)&Methods::scrBGM,
-			(Check)&Checks::chkBGM},
 		{"config", true, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkConfig},
 		{"dialtone", false, (Method)&Methods::scrTone,
@@ -119,13 +91,15 @@ ScriptRuntime()
 			(Check)&Checks::chkSleep},
 		{"route", false, (Method)&Methods::scrRoute,
 			(Check)&Checks::chkRoute},
-#ifdef	WIN32
+#ifdef  WIN32
                 {"link", false, (Method)&Methods::scrCopy,
                         (Check)&Checks::chkMove},
 #else
                 {"link", false, (Method)&Methods::scrLink,
                         (Check)&Checks::chkMove},
 #endif
+		{"write", false, (Method)&Methods::scrWrite,
+			(Check)&Checks::chkWrite},
 		{"copy", false, (Method)&Methods::scrCopy,
 			(Check)&Checks::chkMove},
 		{"move", false, (Method)&Methods::scrMove,
@@ -158,10 +132,6 @@ ScriptRuntime()
 			(Check)&Checks::chkPathname},
 		{"play", false, (Method)&Methods::scrPlay,
 			(Check)&Checks::chkPathname},
-		{"xmlbind", false, (Method)&Methods::scrBind,
-			(Check)&Checks::chkBind},
-                {"xml", false, (Method)&Methods::scrBind,
-                        (Check)&Checks::chkBind}, 
         	{NULL, false, NULL, NULL}};
 
         trap("timeout", false);
@@ -330,9 +300,9 @@ bool Runtime::isInput(Line *line)
 	if(line->scr.method == (Method)&Methods::scrInput)
 		return true;
 
-        if(line->scr.method == (Method)&Methods::scrRead)  
-                return true;
-                               
+	if(line->scr.method == (Method)&Methods::scrRead)
+		return true;
+
 	if(line->scr.method == (Method)&Methods::scrCleardigits)
 		return true;
 
@@ -342,19 +312,6 @@ bool Runtime::isInput(Line *line)
 	return false;
 }
 
-bool Runtime::testBinding(ScriptInterp *interp, const char *v)
-{
-	const char *cp = keyserver.getLast("binding");
-
-	if(!v || !cp)
-		return false;
-
-	if(!stricmp(cp, v))
-		return true;
-
-	return false;
-}
-
 bool Runtime::testDriver(ScriptInterp *interp, const char *v)
 {
 	if(BayonneDriver::get(v))
@@ -367,7 +324,7 @@ bool Runtime::testFile(ScriptInterp *interp, const char *v)
 {
 	BayonneSession *s = (BayonneSession *)(interp);
 	char buf[MAX_PATHNAME];
-	char *ext;
+	const char *ext;
 
 	if(!v || !*v)
 		return false;
@@ -540,146 +497,11 @@ static void readline(char *buf, unsigned max)
         buf[count] = 0;
 }
 
-bool Runtime::startSelect(const char *name, const char *dial, const char *caller, const char *display)
-{
-	BayonneDriver *trunk = BayonneDriver::getTrunking();
-	BayonneSpan *span;
-	BayonneSession *session;
-	ScriptImage *img = useImage();
-	Name *scr = img->getScript(name);
-	Event event;
-	Line *sel;
-	unsigned idx = 0, count;
-	const char *cp;
-	timeslot_t pos;
-
-	if(!scr || !scr->select || scr->access != scrPUBLIC)
-	{
-		endImage(img);
-		if(trunk && scr)
-			return startDriver(trunk, name, dial, caller, display);
-		return false;
-	}
-
-	sel = scr->select;
-	
-	while(sel)
-	{
-                idx = 0;
-                cp = strchr(cp, '.');
-                if(cp && !stricmp(cp, ".span"))
-                     while(NULL != (cp = sel->args[idx++]))
-                {
-                        span = BayonneSpan::get(atoi(cp));
-                        if(!span)   
-                                continue;
-
-                        pos = span->getFirst();
-                        count = span->getCount();     
-                        while(count--)
-                        {
-                                session = getSession(pos++);
-                                if(!session)
-                                        continue;
-
-                                session->enter();
-                                if(session->isIdle())
-                                        goto start;
-                                session->leave();
-                        }
-		}
-                else while(NULL != (cp = sel->args[idx++]))
-                {
-                        session = getSid(cp);
-                        if(!session)
-                                continue;
-
-                        session->enter();
-                        if(session->isIdle())
-                                goto start;
-                        session->leave();
-                }
-		sel = sel->next;
-
-	}
-	endImage(img);
-	return false;
-
-start:
-        memset(&event, 0, sizeof(event));
-        event.id = START_OUTGOING;
-        event.start.img = img; 
-        event.start.scr = scr;
-        event.start.dialing = dial;
-
-        session->setConst("session.caller", caller);
-        session->setConst("session.display", display);
-
-        if(!session->postEvent(&event))
-        {
-                session->leave();
-                endImage(img);
-                return false;
-        }
-
-	session->leave();
-	return true;
-}
-
-bool Runtime::startDriver(BayonneDriver *d, const char *name, const char *dial, const char *caller, const char *display)
-{
-	BayonneSession *session;
-	ScriptImage *img = useImage();
-	Name *scr = img->getScript(name);
-	Event event;
-
-	if(!d || !scr || scr->access != scrPUBLIC)
-	{
-		endImage(img);
-		return false;
-	}
-
-	if(!caller)
-	{
-		display = "bayonne";
-		caller = "none";
-	}
-
-	if(!display)
-		display = caller;
-
-	session = d->getIdle();
-	if(!session)
-	{
-		endImage(img);
-		return false;
-	}
-
-	memset(&event, 0, sizeof(event));
-	event.id = START_OUTGOING;
-	event.start.img = img;
-	event.start.scr = scr;
-	event.start.dialing = dial;
-
-	session->enter();
-	session->setConst("session.caller", caller);
-	session->setConst("session.display", display);
-
-	if(!session->postEvent(&event))
-	{
-		session->leave();
-		endImage(img);
-		return false;
-	}
-
-	session->leave();
-	return true;
-}
-
 bool Runtime::command(char *cmd)
 {
 	Event event;
 	char *tok;
+	const char *sym, *val;
 	static fstream *logout = NULL;
 	BayonneSession *s;
 	const char *cp;
@@ -687,6 +509,9 @@ bool Runtime::command(char *cmd)
 	BayonneDriver *d;
 	const char *dial, *caller, *display;
 	char buf[65];
+	const char *args[65];
+	int argc = 0;
+	char *sp;
 
 	cmd = strtok_r(cmd, " \t\r\n", &tok);
 	if(!cmd || ispunct(*cmd) || !*cmd)
@@ -700,14 +525,20 @@ bool Runtime::command(char *cmd)
 
 	if(!stricmp(cmd, "start"))
 	{
-		cmd = strtok_r(NULL, " \t\r\n", &tok);
-		if(!cmd)
-			return false;
 		dial = strtok_r(NULL, " \t\r\n", &tok);
+
+		cmd = strtok_r(NULL, " \t\r\n", &tok);
+		if(!cmd || !dial)
+			return false;
+
 		caller = strtok_r(NULL, " \t\r\n", &tok);
 		display = strtok_r(NULL, " \t\r\n", &tok);
-		return startSelect(cmd, dial, caller, display);
-	}			
+		s = startDialing(dial, cmd, caller, display);
+		if(!s)
+			return false;
+		s->leave();
+		return true;
+	}	
 
 	if(!strnicmp(cmd, "lang", 4))
 	{
@@ -720,15 +551,39 @@ bool Runtime::command(char *cmd)
 		return true;
 	}
 		
-	if(!stricmp(cmd, "define"))
+        if(!stricmp(cmd, "define"))
+        {
+                cmd = strtok_r(NULL, " \t\r\n", &tok);
+                if(!cmd)
+                        return false;
+
+                snprintf(buf, sizeof(buf), "%s.def", cmd);
+                Bayonne::server->setValue("definitions", buf);
+                return true;
+        }
+
+	if(!stricmp(cmd, "global") || !stricmp(cmd, "symbol"))
 	{
+		sym = strtok_r(NULL, " \t\r\n", &tok);
 		cmd = strtok_r(NULL, " \t\r\n", &tok);
-		if(!cmd)
+		val = strtok_r(NULL, " \t\r\n", &tok);
+
+		if(!sym || !cmd)
 			return false;
 
-		snprintf(buf, sizeof(buf), "%s.def", cmd);
-		Bayonne::server->setValue("definitions", buf);
-		return true;
+		if(!val && stricmp(cmd, "clear"))
+			return false;
+		
+		if(!stricmp(cmd, "set"))
+			return BayonneSession::setGlobal(sym, val);
+		else if(!stricmp(cmd, "size"))
+			return BayonneSession::sizeGlobal(sym, atoi(val));
+		else if(!stricmp(cmd, "add"))
+			return BayonneSession::addGlobal(sym, val);
+		else if(!stricmp(cmd, "clear"))
+			return BayonneSession::clearGlobal(sym);
+		else
+			return false;
 	}
 
 	if(!stricmp(cmd, "load"))
@@ -786,23 +641,27 @@ skipcerr1:
 			return false;
 		return service(cmd);
 	}
-	
-	if(!stricmp(cmd, "reload"))
-	{
-		Bayonne::reload();
-		return true;
-	}
-	
-	d = BayonneDriver::get(cmd);
-	if(d)
+
+	if(!stricmp(cmd, "submit"))
 	{
 		cmd = strtok_r(NULL, " \t\r\n", &tok);
 		if(!cmd)
 			return false;
-		dial = strtok_r(NULL, " \t\r\n", &tok);
-		caller = strtok_r(NULL, " \t\r\n", &tok);
-		display = strtok_r(NULL, " \t\r\n", &tok);
-		return startDriver(d, cmd, dial, caller, display);
+
+		args[argc++] = cmd;
+		while(NULL != (cmd = strtok_r(NULL, " \t\r\n", &tok)) && argc < 60)
+			args[argc++] = cmd;
+
+		args[argc] = NULL;
+		if(BayonneBinder::submitRequest(args))
+			return true;
+		return false;
+	}
+		
+	if(!stricmp(cmd, "reload"))
+	{
+		Bayonne::reload();
+		return true;
 	}
 
 	slog.error("fifo: unknown command %s", cmd);
@@ -844,17 +703,11 @@ void Runtime::process(void)
 		fclose(fp);
 	}
 
-	if(Bayonne::provision_gateway)
-		snprintf(buf, sizeof(buf), "%s/gateway.ctrl",
-			keypaths.getLast("runfiles"));
-	else			
-		snprintf(buf, sizeof(buf), "%s/bayonne.ctrl", 
-			keypaths.getLast("runfiles"));
-	slog.debug("fifo=%s", buf);
+	snprintf(buf, sizeof(buf), "%s/%s.ctrl", keypaths.getLast("runfiles"), argv0);
 	remove(buf);
 	mkfifo(buf, 0770);
-	keypaths.setValue("runfifo", buf);
 	fifo = ::open(buf, O_RDWR);
+	keypaths.setValue("runfifo", buf);
 	for(;;)
 	{
 		readline(buf, sizeof(buf));
@@ -901,7 +754,7 @@ bool Runtime::loadBinder(const char *path)
 #endif
 #endif   
         if(!prefix)
-   	 		prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binders";
+	 	prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binders";
 #else
 
 #ifdef  HAVE_TESTING
@@ -941,7 +794,7 @@ bool Runtime::loadBinder(const char *path)
 
         if(!canAccess(path))
         {
-                Bayonne::errlog("access", "cannot load binder %s", path);
+                Bayonne::errlog("access", "cannot load  %s", path);
                 return false;
         }  
 
@@ -954,7 +807,7 @@ bool Runtime::loadBinder(const char *path)
                 return false;
         }
         setValue(path, "loaded");
-	ripple = Bayonne::provision_ripple;
+	ripple = false;
         return true;
 }                     
 		
